@@ -37,7 +37,7 @@ App::Pod - Quickly show available class methods and documentation.
 
 =cut
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 
 =head1 SYNOPSIS
@@ -1342,7 +1342,7 @@ Install bash completion support.
 
 Install tab completion.
 
- % source bashrc_pod
+ % source bash_completion_pod
 
 =head1 SEE ALSO
 
